
local json = require( "json" )
local admob = require( "plugin.admob" )
local admobTapjoy = require( "plugin.admobtapjoy" )

local adProvider = {}
adProvider.options = {}
adProvider.isReady = false
adProvider.justRewarded = false
adProvider.providerName = "admob"
adProvider.childSafe = false
adProvider.userIdSet = false

adProvider.adListener = function(event)
    
    if adProvider.options.debug == true then
        print("+++++Admob:",json.prettify(event))
    end
     
    if event.phase == "init" then  -- Successful initialization

        adProvider.isReady = true 
        admob.load( "interstitial", { 
            adUnitId = adProvider.options.keys["interstitial"], 
            hasUserConsent = adProvider.options.consent,
            childSafe =  adProvider.childSafe
        }
        )

        admob.load( "rewardedVideo", { 
            adUnitId = adProvider.options.keys["rewardedVideo"], 
            hasUserConsent = adProvider.options.consent,
            childSafe =  adProvider.childSafe
        } 
        )

        admob.load( "banner", { 
            adUnitId = adProvider.options.keys["banner"], 
            hasUserConsent = adProvider.options.consent,
            childSafe =  adProvider.childSafe
        } 
        )
        
        adProvider.options.dispatcher:dispatchEvent( { name="ads", provider=adProvider.providerName, type="", phase="init"  } )
            
	elseif event.type == "rewardedVideo" and event.phase == "reward" then
		adProvider.options.dispatcher:dispatchEvent( { name="ads", provider=adProvider.providerName, phase="reward"  } ) 

    else
        adProvider.options.dispatcher:dispatchEvent( { name="ads", provider=adProvider.providerName, type= event.type, phase= event.phase } ) 

        if event.phase == "loaded" and adProvider.userIdSet == false then
            adProvider.userIdSet = true
        end
        
    end

    if event.phase == "closed" then
        admob.load( event.type, { 
            adUnitId = adProvider.options.keys[event.type], 
            hasUserConsent = adProvider.options.consent,
            childSafe =  adProvider.childSafe
        } 
        )
    end
end

adProvider.isAvailable = function(adType)

    if adType == "interstitial" or adType == "rewardedVideo" or adType == "banner" then
        
        local isLoaded = admob.isLoaded( adType )

        if isLoaded == false then 
            admob.load( adType, { 
                adUnitId = adProvider.options.keys[adType], 
                hasUserConsent = adProvider.options.consent,
                childSafe =  adProvider.childSafe
            } 
            )


        end

        return isLoaded
    end

    return false

end

adProvider.show = function(adType, opt)
    if adProvider.isReady == true then
        
        if adProvider.isAvailable(adType)  then

            if adType == "banner" then
                admob.show( "banner", { y = opt.y} )
                return true
            else 
                admob.show(adType)
                return true
            end
            
        else
            return false
        end
    else
        return false
    end
end

adProvider.hide = function(adType)
    if adType == "banner" then
        admob.hide()
    end
end

adProvider.init = function(options)
    adProvider.options = options

    local underAge = false
    if options.belowConsentAge == true or options.coppaUnderAge == true or options.gdprUnderAge == true then
        adProvider.childSafe = true
        underAge = true
    

    end

    admobTapjoy.setPrivacy( {underAge = underAge, subjectToConsent = false})
    admobTapjoy.setDebug( true )
    admobTapjoy.setUserID( adProvider.options.userId )
            
    admob.init( adProvider.adListener, { testMode = adProvider.options.debug } )
    --adProvider.options.debug
end


return adProvider